@@ -10,11 +10,11 @@ Archive::Har::Browser - Represents the browser that created of the HTTP Archive
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -57,11 +57,21 @@ sub new {
 	bless $self, $class;
 	foreach my $key (sort { $a cmp $b } keys %_fields) {
 		next unless (defined $params->{$key});
-		$self->$key($params->{$key});
+		my $key_class = ref $params->{$key};
+		if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+			$self->$key($params->{$key} ? 1 : 0);
+		} else {
+			$self->$key($params->{$key});
+		}
 	}
 	foreach my $key (sort { $a cmp $b } keys %$params) {
 		if ($key =~ /^_/) { # check for private fields
-			$self->$key($params->{$key});
+			my $key_class = ref $params->{$key};
+			if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+				$self->$key($params->{$key} ? 1 : 0);
+			} else {
+				$self->$key($params->{$key});
+			}
 		}
 	}
 	return $self;
@@ -100,6 +110,9 @@ sub TO_JSON {
 		next unless (defined $self->{$key});
 		$json->{$key} = $self->{$key};
 	}
+	$json->{name} //= 'Unknown';
+	$json->{version} //= 'Unknown';
+	$json->{version} = "$json->{version}";
 	return $json;
 }
 
