@@ -14,11 +14,11 @@ Archive::Har::Entry - Represents a single http request/response pair inside the
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -65,6 +65,26 @@ returns the reference to the parent page.  This may be null.
 
 returns the date and time stamp for the beginning of the request (ISO 8601 format)
 
+=cut
+
+sub startedDateTime {
+	my ($self, $new) = @_;
+	my $old = $self->{startedDateTime};
+	$old //= '0000-00-00T00:00:00.0+00:00';
+	if (@_ > 1) {
+		if (defined $new) {
+			if ($new =~ /^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d+(?:\+\d{2}:\d{2}|Z)$/smx) {
+				$self->{startedDateTime} = $new;
+			} else {
+				Carp::croak("startedDateTime is not formatted correctly:$new");
+			}
+		} else {
+			$self->{startedDateTime} = undef;
+		}
+	}
+	return $old;
+}
+
 =head2 time
 
 returns the total elapsed time of the request in milliseconds.  It is the sum of all the timings available in the timings object (not including undefined values).
@@ -106,10 +126,34 @@ sub time {
 
 returns the request object
 
+=cut
+
+sub request {
+	my ($self, $request) = @_;
+	my $old = $self->{request};
+	$old //= Archive::Har::Entry::Request->new();
+	if (@_ > 1) {
+		$self->{request} = Archive::Har::Entry::Request->new($request);
+	}
+	return $old;
+}
+
 =head2 response
 
 returns the response object
 
+=cut
+
+sub response {
+	my ($self, $response) = @_;
+	my $old = $self->{response};
+	$old //= Archive::Har::Entry::Response->new();
+	if (@_ > 1) {
+		$self->{response} = Archive::Har::Entry::Response->new($response);
+	}
+	return $old;
+}
+
 =head2 cache
 
 returns the cache object
@@ -137,7 +181,6 @@ sub new {
 	my $self = {};
 	bless $self, $class;
 	foreach my $key (sort { $a cmp $b } keys %_fields) {
-		next unless (defined $params->{$key});
 		if ($key eq 'request') {
 			$self->{$key} = Archive::Har::Entry::Request->new($params->{$key});
 		} elsif ($key eq 'response') {
@@ -147,12 +190,22 @@ sub new {
 		} elsif ($key eq 'timings') {
 			$self->{$key} = Archive::Har::Entry::Timings->new($params->{$key});
 		} else {
-			$self->$key($params->{$key});
+			my $key_class = ref $params->{$key};
+			if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+				$self->$key($params->{$key} ? 1 : 0);
+			} else {
+				$self->$key($params->{$key});
+			}
 		}
 	}
 	foreach my $key (sort { $a cmp $b } keys %$params) {
 		if ($key =~ /^_/) { # check for private fields
-			$self->$key($params->{$key});
+			my $key_class = ref $params->{$key};
+			if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+				$self->$key($params->{$key} ? 1 : 0);
+			} else {
+				$self->$key($params->{$key});
+			}
 		}
 	}
 	return $self;
@@ -188,8 +241,8 @@ sub TO_JSON {
 	my ($self) = @_;
 	my $json = {};
 	foreach my $key (sort { $a cmp $b } keys %$self) {
-		next unless (defined $self->{$key});
-		$json->{$key} = $self->{$key};
+		next if (!defined $self->$key());
+		$json->{$key} = $self->$key();
 	}
 	if (defined $self->time()) {
 		$json->{time} = $self->time();
