@@ -11,11 +11,11 @@ Archive::Har::Entry::Cache - Represents the cache for a single request/response
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -83,11 +83,21 @@ sub new {
 	bless $self, $class;
 	foreach my $key (sort { $a cmp $b } keys %_fields) {
 		next unless (defined $params->{$key});
-		$self->$key($params->{$key});
+		my $key_class = ref $params->{$key};
+		if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+			$self->$key($params->{$key} ? 1 : 0);
+		} else {
+			$self->$key($params->{$key});
+		}
 	}
 	foreach my $key (sort { $a cmp $b } keys %$params) {
 		if ($key =~ /^_/) { # check for private fields
-			$self->$key($params->{$key});
+			my $key_class = ref $params->{$key};
+			if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+				$self->$key($params->{$key} ? 1 : 0);
+			} else {
+				$self->$key($params->{$key});
+			}
 		}
 	}
 	return $self;
@@ -126,12 +136,8 @@ sub TO_JSON {
 		next unless (defined $self->{$key});
 		$json->{$key} = $self->{$key};
 	}
-	unless (exists $json->{beforeRequest}) {
-		$json->{beforeRequest} = undef;
-	}
-	unless (exists $json->{afterRequest}) {
-		$json->{beforeRequest} = undef;
-	}
+	$json->{beforeRequest} //= Archive::Har::Entry::Cache::Request->new();
+	$json->{afterRequest} //= Archive::Har::Entry::Cache::Request->new();
 	return $json;
 }
 
