@@ -10,11 +10,11 @@ Archive::Har::Entry::Cache::Request - Represents a cache request for a cache ins
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -75,11 +75,21 @@ sub new {
 	bless $self, $class;
 	foreach my $key (sort { $a cmp $b } keys %_fields) {
 		next unless (defined $params->{$key});
-		$self->$key($params->{$key});
+		my $key_class = ref $params->{$key};
+		if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+			$self->$key($params->{$key} ? 1 : 0);
+		} else {
+			$self->$key($params->{$key});
+		}
 	}
 	foreach my $key (sort { $a cmp $b } keys %$params) {
 		if ($key =~ /^_/) { # check for private fields
-			$self->$key($params->{$key});
+			my $key_class = ref $params->{$key};
+			if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+				$self->$key($params->{$key} ? 1 : 0);
+			} else {
+				$self->$key($params->{$key});
+			}
 		}
 	}
 	return $self;
@@ -118,6 +128,10 @@ sub TO_JSON {
 		next unless (defined $self->{$key});
 		$json->{$key} = $self->{$key};
 	}
+	$json->{expires} //= '0000-00-00T00-00-00';
+	$json->{lastAccess} //= '0000-00-00T00-00-00';
+	$json->{eTag} //= '';
+	$json->{hitCount} //= 0;
 	return $json;
 }
 
