@@ -14,11 +14,11 @@ Archive::Har::Entry::Request - Represents a single http request inside the HTTP
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -65,14 +65,50 @@ my (%_fields) = (
 
 returns the request method
 
+=cut
+
+sub method {
+	my ($self, $method) = @_;
+	my $old = $self->{method};
+	$old //= 'GET';
+	if (@_ > 1) {
+		$self->{method} = uc $method;
+	}
+	return $old;
+}
+
 =head2 url
 
 returns the absolute url of the request (excluding fragments)
 
+=cut
+
+sub url {
+	my ($self, $url) = @_;
+	my $old = $self->{url};
+	$old //= 'http://example.com/';
+	if (@_ > 1) {
+		$self->{url} = $url;
+	}
+	return $old;
+}
+
 =head2 httpVersion
 
 returns the version of the http request
 
+=cut
+
+sub httpVersion {
+	my ($self, $http_version) = @_;
+	my $old = $self->{httpVersion};
+	$old //= 'HTTP/0.9';
+	if (@_ > 1) {
+		$self->{httpVersion} = uc $http_version;
+	}
+	return $old;
+}
+
 =head2 headers
 
 returns a list of http header objects
@@ -81,7 +117,7 @@ returns a list of http header objects
 
 sub headers {
 	my ($self, $headers) = @_;
-	my $old = $self->{headers} || [];
+	my $old = $self->{headers} // [];
 	if (@_ > 1) {
 		$self->{headers} = [];
 		foreach my $header (@$headers) {
@@ -99,7 +135,7 @@ returns a list of http cookie objects
 
 sub cookies {
 	my ($self, $cookies) = @_;
-	my $old = $self->{cookies} || [];
+	my $old = $self->{cookies} // [];
 	if (@_ > 1) {
 		$self->{cookies} = [];
 		foreach my $cookie (@$cookies) {
@@ -117,7 +153,7 @@ returns a list of the individual objects in the query string
 
 sub queryString {
 	my ($self, $queryString) = @_;
-	my $old = $self->{queryString} || [];
+	my $old = $self->{queryString} // [];
 	if (@_ > 1) {
 		$self->{queryString} = [];
 		foreach my $queryString (@$queryString) {
@@ -135,7 +171,7 @@ returns the post data object.  This may return undef if the postData is not defi
 
 sub postData {
 	my ($self, $postData) = @_;
-	my $old = $self->{postData} || undef;
+	my $old = $self->{postData};
 	if (@_ > 1) {
 		if (defined $postData) {
 			$self->{postData} = Archive::Har::Entry::Request::PostData->new($postData);
@@ -155,14 +191,14 @@ returns the total number of bytes in the http request up to and including the do
 sub headersSize {
 	my ($self, $headersSize) = @_;
 	my $old = $self->{headersSize};
-	if ((defined $old) && ($old eq '-1')) {
+	if ((defined $old) && ($old == -1)) {
 		$old = undef;
 	}
 	if (@_ > 1) {
-		if (defined $headersSize) {
-			$self->{headersSize} = $headersSize;
+		if ((defined $headersSize) && ($headersSize =~ /^(\d+)$/)) {
+			$self->{headersSize} = $1 + 0;
 		} else {
-			$self->{headersSize} = '-1';
+			$self->{headersSize} = -1;
 		}
 	}
 	return $old;
@@ -177,12 +213,12 @@ returns the total number of bytes in the http request body
 sub bodySize {
 	my ($self, $bodySize) = @_;
 	my $old = $self->{bodySize};
-	if ((defined $old) && ($old eq '-1')) {
+	if ((defined $old) && ($old == -1)) {
 		$old = undef;
 	}
 	if (@_ > 1) {
-		if (defined $bodySize) {
-			$self->{bodySize} = $bodySize;
+		if ((defined $bodySize) && ($bodySize =~ /^(\d+)$/)) {
+			$self->{bodySize} = $1 + 0;
 		} else {
 			$self->{bodySize} = '-1';
 		}
@@ -202,11 +238,21 @@ sub new {
 	bless $self, $class;
 	foreach my $key (sort { $a cmp $b } keys %_fields) {
 		next unless (defined $params->{$key});
-		$self->$key($params->{$key});
+		my $key_class = ref $params->{$key};
+		if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+			$self->$key($params->{$key} ? 1 : 0);
+		} else {
+			$self->$key($params->{$key});
+		}
 	}
 	foreach my $key (sort { $a cmp $b } keys %$params) {
 		if ($key =~ /^_/) { # check for private fields
-			$self->$key($params->{$key});
+			my $key_class = ref $params->{$key};
+			if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+				$self->$key($params->{$key} ? 1 : 0);
+			} else {
+				$self->$key($params->{$key});
+			}
 		}
 	}
 	return $self;
@@ -241,15 +287,21 @@ sub AUTOLOAD {
 sub TO_JSON {
 	my ($self) = @_;
 	my $json = {};
-	foreach my $key (sort { $a cmp $b } keys %$self) {
-		next unless (defined $self->{$key});
+	foreach my $key (sort { $a cmp $b } keys %_fields) {
 		next if (
 			($key eq 'headers') ||
 			($key eq 'cookies') ||
 			($key eq 'queryString') ||
 			($key eq 'postData')
 		);
-		$json->{$key} = $self->{$key};
+		if (defined $self->$key()) {
+			$json->{$key} = $self->$key();
+		}
+	}
+	foreach my $key ('bodySize', 'headersSize') {
+		if (!defined $json->{$key}) {
+			$json->{$key} = -1;
+		}
 	}
 	$json->{headers} = [ $self->headers() ];
 	$json->{cookies} = [ $self->cookies() ];
