@@ -11,11 +11,11 @@ Archive::Har::Entry::Request::PostData - Represents a single name/value pair fro
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -102,11 +102,21 @@ sub new {
 	bless $self, $class;
 	foreach my $key (sort { $a cmp $b } keys %_fields) {
 		next unless (defined $params->{$key});
-		$self->$key($params->{$key});
+		my $key_class = ref $params->{$key};
+		if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+			$self->$key($params->{$key} ? 1 : 0);
+		} else {
+			$self->$key($params->{$key});
+		}
 	}
 	foreach my $key (sort { $a cmp $b } keys %$params) {
 		if ($key =~ /^_/) { # check for private fields
-			$self->$key($params->{$key});
+			my $key_class = ref $params->{$key};
+			if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+				$self->$key($params->{$key} ? 1 : 0);
+			} else {
+				$self->$key($params->{$key});
+			}
 		}
 	}
 	return $self;
