@@ -11,11 +11,11 @@ Archive::Har::Page - Represents a single page inside the HTTP Archive
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -71,21 +71,67 @@ sub new {
 	my $self = {};
 	bless $self, $class;
 	foreach my $key (sort { $a cmp $b } keys %_fields) {
-		next unless (defined $params->{$key});
 		if ($key eq 'pageTimings') {
 			$self->$key(Archive::Har::Page::PageTimings->new($params->{$key}));
 		} else {
-			$self->$key($params->{$key});
+			my $key_class = ref $params->{$key};
+			if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+				$self->$key($params->{$key} ? 1 : 0);
+			} else {
+				$self->$key($params->{$key});
+			}
 		}
 	}
 	foreach my $key (sort { $a cmp $b } keys %$params) {
 		if ($key =~ /^_/) { # check for private fields
-			$self->$key($params->{$key});
+			my $key_class = ref $params->{$key};
+			if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+				$self->$key($params->{$key} ? 1 : 0);
+			} else {
+				$self->$key($params->{$key});
+			}
 		}
 	}
 	return $self;
 }
 
+sub startedDateTime {
+	my ($self, $new) = @_;
+	my $old = $self->{startedDateTime};
+	$old //= '0000-00-00T00:00:00.0+00:00';
+	if (@_ > 1) {
+		if (defined $new) {
+			if ($new =~ /^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}\.\d+(?:\+\d{2}:\d{2}|Z)$/smx) {
+				$self->{startedDateTime} = $new;
+			} else {
+				Carp::croak("startedDateTime is not formatted correctly:$new");
+			}
+		} else {
+			$self->{startedDateTime} = undef;
+		}
+	}
+	return $old;
+}
+
+sub id {
+	my ($self, $new) = @_;
+	my $old = $self->{id};
+	if (@_ > 1) {
+		$self->{id} = $new;
+	}
+	return $old;
+}
+
+sub title {
+	my ($self, $new) = @_;
+	my $old = $self->{title};
+	$old //= 'unknown';
+	if (@_ > 1) {
+		$self->{title} = $new;
+	}
+	return $old;
+}
+
 sub AUTOLOAD {
 	my $self = shift;
 	my $type = ref($self) or Carp::croak "$self is not an object";
@@ -116,8 +162,8 @@ sub TO_JSON {
 	my ($self) = @_;
 	my $json = {};
 	foreach my $key (sort { $a cmp $b } keys %$self) {
-		next unless (defined $self->{$key});
-		$json->{$key} = $self->{$key};
+		next if (!defined $self->$key());
+		$json->{$key} = $self->$key();
 	}
 	return $json;
 }
