@@ -10,11 +10,11 @@ Archive::Har::Page::PageTimings - Represents detailed timing of page within the
 
 =head1 VERSION
 
-Version 0.05
+Version 0.06
 
 =cut
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 SYNOPSIS
 
@@ -47,16 +47,20 @@ returns the number of milliseconds since $har->page()->startedDateTime() that th
 =cut
 
 sub onContentLoad {
-	my ($self, $onContentLoad) = @_;
+	my ($self, $on_content_load) = @_;
 	my $old = $self->{onContentLoad};
-	if ((defined $old) && ($old eq '-1')) {
+	if ((defined $old) && ($old == -1)) {
 		$old = undef;
 	}
 	if (@_ > 1) {
-		if (defined $onContentLoad) {
-			$self->{onContentLoad} = $onContentLoad;
+		if (defined $on_content_load) {
+			if ($on_content_load =~ /^(\d+|-1)$/smx) { 
+				$self->{onContentLoad} = $1 + 0;
+			} else {
+				Carp::croak("onContentLoad must be a positive number or -1:$on_content_load");
+			}
 		} else {
-			$self->{onContentLoad} = '-1';
+			$self->{onContentLoad} = -1;
 		}
 	}
 	return $old;
@@ -69,16 +73,20 @@ returns the number of milliseconds since $har->page()->startedDateTime() that th
 =cut
 
 sub onLoad {
-	my ($self, $onLoad) = @_;
+	my ($self, $on_load) = @_;
 	my $old = $self->{onLoad};
-	if ((defined $old) && ($old eq '-1')) {
+	if ((defined $old) && ($old == -1)) {
 		$old = undef;
 	}
 	if (@_ > 1) {
-		if (defined $onLoad) {
-			$self->{onLoad} = $onLoad;
+		if (defined $on_load) {
+			if ($on_load =~ /^(\d+|\-1)$/smx) { 
+				$self->{onLoad} = $1 + 0;
+			} else {
+				Carp::croak("onLoad must be a positive number or -1:$on_load");
+			}
 		} else {
-			$self->{onLoad} = '-1';
+			$self->{onLoad} = -1;
 		}
 	}
 	return $old;
@@ -96,11 +104,21 @@ sub new {
 	bless $self, $class;
 	foreach my $key (sort { $a cmp $b } keys %_fields) {
 		next unless (defined $params->{$key});
-		$self->$key($params->{$key});
+		my $key_class = ref $params->{$key};
+		if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+			$self->$key($params->{$key} ? 1 : 0);
+		} else {
+			$self->$key($params->{$key});
+		}
 	}
 	foreach my $key (sort { $a cmp $b } keys %$params) {
 		if ($key =~ /^_/) { # check for private fields
-			$self->$key($params->{$key});
+			my $key_class = ref $params->{$key};
+			if ((defined $key_class) && ($key_class =~ /^JSON.*?Boolean$/smx)) {
+				$self->$key($params->{$key} ? 1 : 0);
+			} else {
+				$self->$key($params->{$key});
+			}
 		}
 	}
 	return $self;
